==> pdfhandoutcrop-0.3.2.tar.gz: pdfhandoutcrop-0.3.2/pdfhandoutcrop/language/pdfhandoutcrop.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>PdfHandoutCrop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="70"/>
        <source>&amp;Auto detect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="77"/>
        <source>Pages per sheet:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>Zoom &amp;in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>Zoom &amp;out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Width and Height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="247"/>
        <source>Click to set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="209"/>
        <source>Position:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="279"/>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="287"/>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="306"/>
        <source>&amp;Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="311"/>
        <source>&amp;Convert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="316"/>
        <source>About &amp;Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="321"/>
        <source>&amp;About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="45"/>
        <source>PDF documents (*.pdf)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="40"/>
        <source>{0} - PdfHandoutCrop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="58"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="76"/>
        <source>Loading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="266"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="80"/>
        <source>Cannot open input file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="219"/>
        <source>Found {0} pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="254"/>
        <source>Please click the upper left point of page {0}</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="260"/>
        <source>Please click the upper left point of any page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="266"/>
        <source>Height should be set first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="285"/>
        <source>Please click the lower right point of the page you clicked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="133"/>
        <source>&amp;Previous</source>
        <comment>previous page</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <source>&amp;Next</source>
        <comment>next page</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="67"/>
        <source>Page {0}</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="149"/>
        <source>Finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="149"/>
        <source>Convert finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="219"/>
        <source>x:</source>
        <comment>x coordinate</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="233"/>
        <source>y:</source>
        <comment>y coordinate</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="116"/>
        <source>&amp;Reload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="58"/>
        <source>&lt;h3&gt;PdfHandoutCrop {0}&lt;/h3&gt;&lt;br&gt;
Author: Hsiu-Ming Chang&lt;br&gt;
e-mail: cges30901@gmail.com&lt;br&gt;
License: GPL v3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="156"/>
        <source>Page can not be found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="156"/>
        <source>Page can not be found. Auto detect only works if pages have border.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="326"/>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SetPagesDialog</name>
    <message>
        <location filename="../setpagesdialog.ui" line="20"/>
        <source>Only one page is detected. Please select layout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../setpagesdialog.ui" line="29"/>
        <source>Columns:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../setpagesdialog.ui" line="60"/>
        <source>Rows:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../setpagesdialog.ui" line="117"/>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../setpagesdialog.ui" line="14"/>
        <source>Select layout</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> pdfhandoutcrop-0.5.0.tar.gz: pdfhandoutcrop-0.5.0/pdfhandoutcrop/language/pdfhandoutcrop.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>PdfHandoutCrop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="70"/>
        <source>&amp;Auto detect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="77"/>
        <source>Pages per sheet:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>Zoom &amp;in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>Zoom &amp;out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="247"/>
        <source>Click to set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="209"/>
        <source>Position:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="279"/>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="287"/>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="311"/>
        <source>&amp;Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="321"/>
        <source>About &amp;Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="326"/>
        <source>&amp;About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="52"/>
        <source>PDF documents (*.pdf)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="46"/>
        <source>{0} - PdfHandoutCrop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="81"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="99"/>
        <source>Loading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="296"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="41"/>
        <source>Cannot open input file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="249"/>
        <source>Found {0} pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="284"/>
        <source>Please click the upper left point of page {0}</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="290"/>
        <source>Please click the upper left point of any page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="296"/>
        <source>Height should be set first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="315"/>
        <source>Please click the lower right point of the page you clicked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="133"/>
        <source>&amp;Previous</source>
        <comment>previous page</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <source>&amp;Next</source>
        <comment>next page</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="90"/>
        <source>Page {0}</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="179"/>
        <source>Finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="219"/>
        <source>x:</source>
        <comment>x coordinate</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="233"/>
        <source>y:</source>
        <comment>y coordinate</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="116"/>
        <source>&amp;Reload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="81"/>
        <source>&lt;h3&gt;PdfHandoutCrop {0}&lt;/h3&gt;&lt;br&gt;
Author: Hsiu-Ming Chang&lt;br&gt;
e-mail: cges30901@gmail.com&lt;br&gt;
License: GPL v3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="186"/>
        <source>Page can not be found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="186"/>
        <source>Page can not be found. Auto detect only works if pages have border.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Width and Height:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="336"/>
        <source>&amp;Website</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>&amp;Donate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>&amp;Project page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="351"/>
        <source>&amp;Blog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="316"/>
        <source>&amp;Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="41"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.py" line="179"/>
        <source>Cropped PDF saved</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SetPagesDialog</name>
    <message>
        <location filename="../setpagesdialog.ui" line="20"/>
        <source>Only one page is detected. Please select layout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../setpagesdialog.ui" line="29"/>
        <source>Columns:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../setpagesdialog.ui" line="60"/>
        <source>Rows:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../setpagesdialog.ui" line="117"/>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../setpagesdialog.ui" line="14"/>
        <source>Select layout</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
